@@ -23,8 +23,6 @@
 
 
 
-
-
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(0, Qt::FramelessWindowHint),
     ui(new Ui::MainWindow)
@@ -75,16 +73,19 @@ void MainWindow::showEvent(QShowEvent* event)
     }
 #endif
 
-void MainWindow::on_pbEdit_clicked()
+
+
+bool MainWindow::eventFilter(QObject *o, QEvent *e )
 {
+  if (e->type()==3)
+  {
         Dialog *w;
         w = new Dialog(0);
-
-        //settingsdlg *w;
-        //w = new settingsdlg(0);
         w->exec();
         SetupThisUi();
         delete w;
+  }
+  return false;
 }
 
 
@@ -148,6 +149,8 @@ void MainWindow::SetupThisUi()
     ui->teMain->setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
     ui->teMain->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     ui->teMain->setReadOnly(true);
+	
+    ui->teMain->installEventFilter( this );
 
 
     QVariant vRed (cltextedit.red());
@@ -165,12 +168,6 @@ void MainWindow::SetupThisUi()
     ui->lblDate->setFont(QFont(fontFamilyName,10,10));
 
 
-    QPalette p = palette();
-    ui->pbEdit->setPalette(p);
-    ui->pbEdit->setStyleSheet( "background-color: rgba( 255, 255, 255, 0% );" );
-    ui->pbEdit->setText("");
-    ui->pbEdit->setFlat(true);
-
 
 #ifdef Q_WS_HILDON
        this->setProperty("FingerScrollable", true);
@@ -182,7 +179,7 @@ void MainWindow::SetupThisUi()
    QString sFirstRun = oSettings->value("notedate","").toString();
    if (sFirstRun == "")
    {
-       ui->teMain->setText("please press the widget for edit mode");
+       ui->teMain->setText("please press twice for the edit mode");
        ui->lblDate->setText(QDateTime::currentDateTime().toString("dd.MM.yyyy   HH:mm"));
 
    } else
